@@ -6,4 +6,4 @@ if tf.__version__ == '2.2.0':
 else:
 	print("Tensorflow version mismatch!. Please check tensorflow isn't imported before installing quick_ml. Restart the session to fix the error.")
 
-import .tfrecords_maker
\ No newline at end of file
+from quick_ml import tfrecords_maker
\ No newline at end of file
